@@ -29,14 +29,23 @@ __version__
 
 """
 
-#pylint:disable=undefined-all-variable
+#pylint:disable=undefined-all-variable, redefined-builtin
 
 from ._meta import version as __version__
 from ._meta import author as __author__
 from ._meta import release as __release__
 from ._meta import contributors as __contributors__
 __license__ = 'MIT License'
-__copyright__ = 'Copyright (c) 2020 Jason Dsouza'
+__copyright__ = """
+Copyright (c) 2020 Jason Dsouza <jasmcaus>
+All Rights Reserved.
+"""
+
+def license():
+    return __license__ 
+
+def copyright():
+    return __copyright__
 
 
 # Preprocessing
@@ -53,11 +62,10 @@ from .utilities import npmean
 from .utilities import to_array
 from .utilities import array
 from .utilities import asarray
-from .utilities import load
+from .utilities import npload
 from .utilities import train_val_split
 from .utilities import get_classes_from_dir
 from .utilities import sort_dict
-# from .utilities import plotAcc
 
 # Opencv-specific methods
 from .opencv import get_opencv_version
@@ -73,6 +81,8 @@ from .opencv import rgb_to_hsv
 from .opencv import rgb_to_lab
 from .opencv import rgb_to_bgr
 from .opencv import url_to_image 
+from .opencv import energy_map 
+from .opencv import color_map 
 from .opencv import translate
 from .opencv import rotate 
 from .opencv import edges 
@@ -88,10 +98,9 @@ from .time import now
 from .resize import resize 
 from .resize import center_crop 
 
-# Image-related
-from .io import imread 
-from .io import imsave 
-
+# Image 
+from .io import imread
+from .io import imsave
 # # Distance
 # from .distance import distance
 
@@ -118,18 +127,15 @@ from .io import imsave
 # from .morph import get_structuring_elem
 # from .morph import hitmiss
 
-# from .pillow import cv_to_pill
-# from .pillow import pill_to_cv
 
-
-# Bringing in configuration variables from configs.py
-from .configs import CROP_CENTRE
-from .configs import CROP_TOP
-from .configs import CROP_LEFT
-from .configs import CROP_RIGHT 
-from .configs import CROP_BOTTOM
-from .configs import VALID_URL_NO_EXIST
-from .configs import INVALID_URL_STRING
+# Bringing in configuration variables from globals.py
+from .globals import CROP_CENTRE
+from .globals import CROP_TOP
+from .globals import CROP_LEFT
+from .globals import CROP_RIGHT 
+from .globals import CROP_BOTTOM
+from .globals import VALID_URL_NO_EXIST
+from .globals import INVALID_URL_STRING
 
 # except ImportError:
 #     import sys 
@@ -154,7 +160,7 @@ def get_caer_methods():
 
 
 # __all__ configs
-from .configs import __all__ as __all_configs__
+from .globals import __all__ as __all_globals__
 from .io import __all__ as __all_io__
 from .resize import __all__ as __all_resize__
 from .opencv import __all__ as __all_opencv__
@@ -162,23 +168,39 @@ from .preprocess import __all__ as __all_preprocess__
 from .time import __all__ as __all_time__
 from .utilities import __all__ as __all_utilities__
 from .visualizations import __all__ as __all_visualizations__
-# from .distance import __all__ as __all_distance__
-# from .convolve import __all__ as __all_convolve__
-# from .morph import __all__ as __all_morph__
 
 from .video import __all__ as __all_video__
 from .preprocessing import __all__ as __all_preprocessing__
 from .data import __all__ as __all_data__
 from .utils import __all__ as __all_utils__
 from .path import __all__ as __all_path__
-# from .filters import __all__ as __all_filters__
+from .filters import __all__ as __all_filters__
+from .distance import __all__ as __all_distance__
+from .morph import __all__ as __all_morph__
 
 
-# __all__ = __all_configs__ + __all_io__ + __all_resize__ + __all_opencv__ + __all_preprocess__ + __all_time__ + __all_utilities__ + __all_visualizations__ + __all_distance__ + __all_convolve__ + __all_morph__ + __all_filters__
-__all__ = __all_configs__ + __all_io__ + __all_resize__ + __all_opencv__ + __all_preprocess__ + __all_time__ + __all_utilities__ + __all_visualizations__
+__all__ = __all_globals__ + __all_io__ + __all_resize__ + __all_opencv__ + __all_preprocess__ + __all_time__ + __all_utilities__ + __all_visualizations__ + __all_filters__ + __all_distance__ + __all_morph__
 
 __all__ += __all_preprocessing__ 
 __all__ += __all_video__ 
 __all__ += __all_data__ 
 __all__ += __all_utils__ 
-__all__ += __all_path__
\ No newline at end of file
+__all__ += __all_path__
+
+# Stop polluting the namespace
+del __all_globals__ 
+del __all_io__ 
+del __all_resize__ 
+del __all_opencv__ 
+del __all_preprocess__ 
+del __all_time__ 
+del __all_utilities__ 
+del __all_visualizations__
+
+del __all_preprocessing__ 
+del __all_video__ 
+del __all_data__ 
+del __all_utils__ 
+del __all_distance__
+del __all_filters__
+del __all_morph__
\ No newline at end of file
