@@ -1,22 +1,32 @@
-# Copyright 2020 The Caer Authors. All Rights Reserved.
-#
-# Licensed under the MIT License (see LICENSE);
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at <https://opensource.org/licenses/MIT>
-#
-# ==============================================================================
+#    _____           ______  _____ 
+#  / ____/    /\    |  ____ |  __ \
+# | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
+# | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
+# | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
+#  \_____\/_/    \_ \______ |_|__\_
+
+# Licensed under the MIT License <http://opensource.org/licenses/MIT>
+# SPDX-License-Identifier: MIT
+# Copyright (c) 2020 The Caer Authors <http://github.com/jasmcaus>
+
 
 
 import cv2 as cv
 # import numpy as np 
 
-from ._checks import _check_target_size
+from ._internal import _check_target_size
 from .opencv import bgr_to_rgb, bgr_to_gray, url_to_image
 from .utils.validators import is_valid_url
 from .path import exists
 from .resize import resize
 
 
+__all__ = [
+    'imread',
+    'imsave'
+]
+
+
 def imread(image_path, target_size=None, channels=3, rgb=False, resize_factor=None, keep_aspect_ratio=False):
     """
         Loads in an image from `image_path`
@@ -83,10 +93,4 @@ def _read_image(image_path):
     
 
 def imsave(filename, img):
-    cv.imwrite(filename, img)
-
-
-__all__ = [
-    'imread',
-    'imsave'
-]
\ No newline at end of file
+    cv.imwrite(filename, img)
\ No newline at end of file
