@@ -1,21 +1,34 @@
-# Copyright 2020 The Caer Authors. All Rights Reserved.
-#
-# Licensed under the MIT License (see LICENSE);
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at <https://opensource.org/licenses/MIT>
-#
-# ==============================================================================
+#    _____           ______  _____ 
+#  / ____/    /\    |  ____ |  __ \
+# | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
+# | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
+# | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
+#  \_____\/_/    \_ \______ |_|__\_
+
+# Licensed under the MIT License <http://opensource.org/licenses/MIT>
+# SPDX-License-Identifier: MIT
+# Copyright (c) 2020 The Caer Authors <http://github.com/jasmcaus>
+
 
 import random
 import time
 
-from .utilities import saveNumpy, get_classes_from_dir, to_array, load
+from .utilities import saveNumpy, get_classes_from_dir, to_array, npload
 from .io import imread
 from .preprocessing import MeanProcess
-from ._checks import _check_target_size, _check_mean_sub_values
+from ._internal import _check_target_size, _check_mean_sub_values
 from .path import listdir, minijoin, exists, list_images
 
 
+__all__ = [
+    'preprocess_from_dir',
+    'sep_train',
+    'shuffle',
+    'reshape',
+    'normalize'
+]
+
+
 def preprocess_from_dir(DIR, 
                         classes=None, 
                         IMG_SIZE=(224,224), 
@@ -93,7 +106,7 @@ def preprocess_from_dir(DIR,
     if destination_filename is not None and exists(destination_filename):
         print('[INFO] Loading from Numpy Files')
         since = time.time()
-        data = load(destination_filename, allow_pickle=True)
+        data = npload(destination_filename, allow_pickle=True)
         end = time.time()
         print('----------------------------------------------')
         print('[INFO] Loaded in {:.0f}s from Numpy Files'.format(end-since))
@@ -256,13 +269,4 @@ def normalize(x, dtype='float32'):
     
     # Converting to float32 and normalizing (float32 saves memory)
     x = x.astype(dtype) / 255
-    return x
-
-
-__all__ = [
-    'preprocess_from_dir',
-    'sep_train',
-    'shuffle',
-    'reshape',
-    'normalize'
-]
\ No newline at end of file
+    return x
\ No newline at end of file
