@@ -1,14 +1,18 @@
-# Copyright 2020 The Caer Authors. All Rights Reserved.
-#
-# Licensed under the MIT License (see LICENSE);
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at <https://opensource.org/licenses/MIT>
-#
-# ==============================================================================
+#    _____           ______  _____ 
+#  / ____/    /\    |  ____ |  __ \
+# | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
+# | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
+# | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
+#  \_____\/_/    \_ \______ |_|__\_
+
+# Licensed under the MIT License <http://opensource.org/licenses/MIT>
+# SPDX-License-Identifier: MIT
+# Copyright (c) 2020 The Caer Authors <http://github.com/jasmcaus>
+
 
 #pylint:disable=pointless-string-statement
 
-from .._checks import _check_mean_sub_values
+from .._internal import _check_mean_sub_values
 from ..path import exists, list_images
 from ..io import imread 
 from ..opencv import mean, merge, split
@@ -20,6 +24,13 @@ from ..utilities import npmean
     Mean subtract must be computed ONLY on the training set and then later applied on the validation/test set
 """
 
+__all__ = [
+    'MeanProcess',
+    'compute_mean',
+    'compute_mean_from_dir',
+    'subtract_mean',
+]
+
 class MeanProcess:
     def __init__(self, mean_sub_values, channels):
         # mean_sub_values is a tuple
@@ -164,12 +175,4 @@ def subtract_mean(data, channels, mean_sub_values):
 
     data = [mean_process.mean_preprocess(img, channels) for img in data]
     
-    return data
-
-
-__all__ = [
-    'MeanProcess',
-    'compute_mean',
-    'compute_mean_from_dir',
-    'subtract_mean',
-]
\ No newline at end of file
+    return data
\ No newline at end of file
