@@ -1,20 +1,30 @@
-# Copyright 2020 The Caer Authors. All Rights Reserved.
-#
-# Licensed under the MIT License (see LICENSE);
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at <https://opensource.org/licenses/MIT>
-#
-# ==============================================================================
+#    _____           ______  _____ 
+#  / ____/    /\    |  ____ |  __ \
+# | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
+# | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
+# | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
+#  \_____\/_/    \_ \______ |_|__\_
+
+# Licensed under the MIT License <http://opensource.org/licenses/MIT>
+# SPDX-License-Identifier: MIT
+# Copyright (c) 2020 The Caer Authors <http://github.com/jasmcaus>
+
 
 import math 
 import cv2 as cv
 
-from ._checks import _check_target_size
-from .configs import (
+from ._internal import _check_target_size
+from .globals import (
     INTER_AREA, INTER_CUBIC, INTER_NEAREST, INTER_LINEAR
 )
 
 
+__all__ = [
+    'center_crop',
+    'resize'
+]
+
+
 def resize(image, target_size=None, resize_factor=None, keep_aspect_ratio=False, interpolation='area'):
     """
         Resizes an image with a specified resizing factor, this factor can also be
@@ -173,10 +183,3 @@ def _compute_centre_crop(image, target_size):
     diff_w = (org_w - target_w ) // 2
     
     return image[diff_h:diff_h + target_h, diff_w:diff_w + target_w]
-
-
-
-__all__ = [
-    'center_crop',
-    'resize'
-]
\ No newline at end of file
