@@ -1,10 +1,14 @@
-# Copyright 2020 The Caer Authors. All Rights Reserved.
-#
-# Licensed under the MIT License (see LICENSE);
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at <https://opensource.org/licenses/MIT>
-#
-# ==============================================================================
+#    _____           ______  _____ 
+#  / ____/    /\    |  ____ |  __ \
+# | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
+# | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
+# | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
+#  \_____\/_/    \_ \______ |_|__\_
+
+# Licensed under the MIT License <http://opensource.org/licenses/MIT>
+# SPDX-License-Identifier: MIT
+# Copyright (c) 2020 The Caer Authors <http://github.com/jasmcaus>
+
 
 from .validators import URLValidator
 from .validators import validate_ipv6_address
@@ -28,8 +32,11 @@ from .warnings import (
     warn
 )
 
-# __all__ configs 
+# __all__ globals 
 from .validators import __all__ as __all_validators__ 
 from .dtype import __all__ as __all_dtype__
 
-__all__ = __all_validators__ + __all_dtype__
\ No newline at end of file
+__all__ = __all_validators__ + __all_dtype__
+
+del __all_dtype__
+del __all_validators__
\ No newline at end of file
