@@ -1,19 +1,22 @@
-# Copyright 2020 The Caer Authors. All Rights Reserved.
-#
-# Licensed under the MIT License (see LICENSE);
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at <https://opensource.org/licenses/MIT>
-#
-# ==============================================================================
+#    _____           ______  _____ 
+#  / ____/    /\    |  ____ |  __ \
+# | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
+# | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
+# | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
+#  \_____\/_/    \_ \______ |_|__\_
+
+# Licensed under the MIT License <http://opensource.org/licenses/MIT>
+# SPDX-License-Identifier: MIT
+# Copyright (c) 2020 The Caer Authors <http://github.com/jasmcaus>
 
 import math
 import time
 import cv2 as cv
 
-from .._checks import _check_target_size
+from .._internal import _check_target_size
 from ..path import list_videos, exists, mkdir
 from ..resize import resize
-from ..configs import FRAME_COUNT, FPS
+from ..globals import FRAME_COUNT, FPS
 from ..io import imsave
 
 
@@ -72,25 +75,28 @@ def extract_frames(input_folder,
         if vid_count < max_video_count:
             capture = cv.VideoCapture(vid_filepath)
             video_frame_counter = 0
+            vid_count += 1
 
             # Find the number of frames and FPS
             video_frame_count = int(capture.get(FRAME_COUNT)) - 1
             video_fps = math.ceil(capture.get(FPS))
             file = vid_filepath[vid_filepath.rindex('/')+1:]
-
-            print(f'{vid_count+1}. Reading \'{file}\'. Number of frames: {video_frame_count}. FPS: {video_fps}')
-
-            if frames_per_sec is not None and frame_interval is None:
-                interval= _determine_interval(video_fps/frames_per_sec) # eg: 30//15
-                # print('Interval: ', interval)
             
-            elif frame_interval is not None:
-                interval = frame_interval
+            if frames_per_sec is not None:
+                if frame_interval is None:
+                    interval = _determine_interval(video_fps/frames_per_sec) # eg: 30//15
+            
+                else:
+                    interval = frame_interval
 
             # if frames_per_sec and frame_interval are both None, we assume that each frame should be processed
             else:
                 interval = 1
             
+            # processed_frames = (video_frame_count//video_fps) * frames_per_sec
+
+            print(f'{vid_count}. Reading \'{file}\'. Frame Count: {video_frame_count}. FPS: {video_fps}. Processed frames: {video_frame_count//interval}')
+            
             # Start converting the video
             while capture.isOpened():
                 _, frame = capture.read()
@@ -100,7 +106,7 @@ def extract_frames(input_folder,
                 
                 # Write the results back to output location as per specified frames per second
                 if video_frame_counter % interval == 0:
-                    imsave(f'{output_folder}/{label_counter}.{dest_filetype}', frame)
+                    imsave(f'{output_folder}/{file}_{label_counter}.{dest_filetype}', frame)
                     video_frame_counter += 1
                     label_counter += 1
                     # print('Frame counter: ', video_frame_counter)
@@ -118,9 +124,13 @@ def extract_frames(input_folder,
     # Printing stats
     taken = end-start
     if processed_videos > 1:
-        print('[INFO] {} videos extracted in {:.2f} seconds'.format(processed_videos, taken ))
+        print('[INFO] {} videos extracted in {:.0f}m {:.0f}s'.format(processed_videos, 
+                                                                    taken // 60,
+                                                                    taken % 60 ))
     else:
-        print('[INFO] {} video extracted in {:.2f} seconds'.format(processed_videos, taken ))
+        print('[INFO] {} video extracted in {:.0f}m {:.0f}s'.format(processed_videos, 
+                                                                    taken // 60,
+                                                                    taken % 60 ))
 
     return label_counter
 
