@@ -1,15 +1,24 @@
-# Copyright 2020 The Caer Authors. All Rights Reserved.
-#
-# Licensed under the MIT License (see LICENSE);
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at <https://opensource.org/licenses/MIT>
-#
-# ==============================================================================
+#    _____           ______  _____ 
+#  / ____/    /\    |  ____ |  __ \
+# | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
+# | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
+# | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
+#  \_____\/_/    \_ \______ |_|__\_
+
+# Licensed under the MIT License <http://opensource.org/licenses/MIT>
+# SPDX-License-Identifier: MIT
+# Copyright (c) 2020 The Caer Authors <http://github.com/jasmcaus>
+
 
 """ 
 Provides visualization-specific functions 
 """
 
+__all__ = [
+    'hex_to_rgb',
+    'draw_rectangle'
+]
+
 
 def hex_to_rgb(x):
     """
@@ -19,13 +28,13 @@ def hex_to_rgb(x):
 
 
 def draw_rectangle(draw, coordinates, color, width=1, fill=30):
-    """Draw a rectangle with an optional width."""
+    """
+        Draw a rectangle with an optional width.
+    """
     # Add alphas to the color so we have a small overlay over the object.
     fill = color + (fill,)
     outline = color + (255,)
 
-    # Pillow doesn't support width in rectangles, so we must emulate it with a
-    # loop.
     for i in range(width):
         coords = [
             coordinates[0] - i,
@@ -39,10 +48,4 @@ def draw_rectangle(draw, coordinates, color, width=1, fill=30):
         if i == 0:
             draw.rectangle(coords, fill=fill, outline=outline)
         else:
-            draw.rectangle(coords, outline=outline)
-
-
-__all__ = [
-    'hex_to_rgb',
-    'draw_rectangle'
-]
\ No newline at end of file
+            draw.rectangle(coords, outline=outline)
\ No newline at end of file
